References
==========

This document contains various references which were helpful in the development
of this library.

X.690
    https://www.itu.int/rec/T-REC-X.690/en

List & Type identifiers of SMI types
    https://tools.ietf.org/html/rfc1155#section-6

GetNextPDU (and others) explained:
    https://tools.ietf.org/html/rfc1157#section-4.1.3

Page 11 shows a PDU example
    https://tools.ietf.org/html/rfc1592

SNMP uses BER
    https://en.wikipedia.org/wiki/X.690#BER_encoding

PDU Packet Structure
    http://www.tcpipguide.com/free/t_SNMPVersion2SNMPv2MessageFormats-5.htm

MSDN Help
    https://msdn.microsoft.com/en-us/library/bb540809(v=vs.85).aspx

ASCII Representation of some PDUs:
    http://www.opencircuits.com/SNMP_MIB_Implementation

Variable Length Quantity (encoding large numbers)
    https://en.wikipedia.org/wiki/Variable-length_quantity

Settable SNMP Values
    http://tomsalmon.eu/2012/02/net-snmp-writeable-attributes/
